Barman, Backup and Recovery Manager for PostgreSQL
==================================================

This is the new (starting with version 2.13) home of Barman. It replaces
the legacy sourceforge repository.

Barman (Backup and Recovery Manager) is an open-source administration
tool for disaster recovery of PostgreSQL servers written in Python. It
allows your organisation to perform remote backups of multiple servers
in business critical environments to reduce risk and help DBAs during
the recovery phase.

Barman is distributed under GNU GPL 3 and maintained by EnterpriseDB.

For further information, look at the "Web resources" section below.

Source content
--------------

Here you can find a description of files and directory distributed with
Barman:

-  AUTHORS : development team of Barman
-  NEWS : release notes
-  ChangeLog : log of changes
-  LICENSE : GNU GPL3 details
-  TODO : our wishlist for Barman
-  barman : sources in Python
-  docs : tutorial and man pages
-  scripts : auxiliary scripts
-  tests : unit tests

Web resources
-------------

-  Website : http://www.pgbarman.org/
-  Download : http://github.com/EnterpriseDB/barman
-  Documentation : http://www.pgbarman.org/documentation/
-  Community support : http://www.pgbarman.org/support/
-  Professional support : https://www.enterprisedb.com/
-  pre barman 2.13 versions : https://sourceforge.net/projects/pgbarman/files/

Licence
-------

© Copyright 2011-2025 EnterpriseDB UK Limited

Barman is free software: you can redistribute it and/or modify it under
the terms of the GNU General Public License as published by the Free
Software Foundation, either version 3 of the License, or (at your
option) any later version.

Barman is distributed in the hope that it will be useful, but WITHOUT
ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for
more details.

You should have received a copy of the GNU General Public License along
with Barman. If not, see http://www.gnu.org/licenses/.
